==> scalarx_2.10-0.2.3-JS.jar: rx/ops/package$RxOps$.js <==
/** @constructor */
ScalaJS.c.rx_ops_package$RxOps$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_ops_package$RxOps$.prototype.constructor = ScalaJS.c.rx_ops_package$RxOps$;
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__Lrx_core_Obs = (function($$this, callback$2, skipInitial$2) {
  return ScalaJS.modules.rx_package().Obs__Lrx_core_Obs$().apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs($$this, ("Foreach " + $$this.name__T()), skipInitial$2, new ScalaJS.c.scala_scalajs_runtime_AnonFunction0().init___Lscala_scalajs_js_Function0((function($$this$1, callback$1) {
    return (function() {
      callback$1.apply__O__O($$this$1.apply__O());
      return ScalaJS.bV(undefined)
    })
  })($$this, callback$2)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$default$2$extension__Lrx_core_Rx__Z = (function($$this) {
  return false
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.skipFailures$extension__Lrx_core_Rx__Lrx_core_Rx = (function($$this) {
  return this.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(x) {
      return ScalaJS.bZ(x.isSuccess__Z())
    })
  })()))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.map$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, f) {
  return new ScalaJS.c.rx_ops_Mapper().init___Lrx_core_Rx__Lscala_Function1($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function(f$1) {
    return (function(y) {
      return y.map__Lscala_Function1__Lscala_util_Try(f$1)
    })
  })(f)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filter$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, successPred) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(successPred$1) {
    return (function(x, y) {
      var x1 = new ScalaJS.c.scala_Tuple2().init___O__O(x, y);
      if ((x1 !== null)) {
        var p3 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p3)) {
          var x4 = ScalaJS.as.scala_util_Success(p3);
          var value = x4.value__O();
          if (ScalaJS.uZ(successPred$1.apply__O__O(value))) {
            return new ScalaJS.c.scala_util_Success().init___O(value)
          }
        }
      };
      if ((x1 !== null)) {
        var p6 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p6)) {
          var x7 = ScalaJS.as.scala_util_Failure(p6);
          var thrown = x7.exception__Ljava_lang_Throwable();
          return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(thrown)
        }
      };
      if ((x1 !== null)) {
        var old = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        return old
      };
      throw new ScalaJS.c.scala_MatchError().init___O(x1)
    })
  })(successPred)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduce$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx = (function($$this, combiner) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(combiner$1) {
    return (function(x, y) {
      var x1 = new ScalaJS.c.scala_Tuple2().init___O__O(x, y);
      if ((x1 !== null)) {
        var p2 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p3 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p2)) {
          var x4 = ScalaJS.as.scala_util_Success(p2);
          var a = x4.value__O();
          if (ScalaJS.is.scala_util_Success(p3)) {
            var x5 = ScalaJS.as.scala_util_Success(p3);
            var b = x5.value__O();
            return new ScalaJS.c.scala_util_Success().init___O(combiner$1.apply__O__O__O(a, b))
          }
        }
      };
      if ((x1 !== null)) {
        var p6 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p7 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p6)) {
          if (ScalaJS.is.scala_util_Success(p7)) {
            var x10 = ScalaJS.as.scala_util_Success(p7);
            var b$2 = x10.value__O();
            return new ScalaJS.c.scala_util_Success().init___O(b$2)
          }
        }
      };
      if ((x1 !== null)) {
        var p11 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p12 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p11)) {
          if (ScalaJS.is.scala_util_Failure(p12)) {
            var x15 = ScalaJS.as.scala_util_Failure(p12);
            var b$3 = x15.exception__Ljava_lang_Throwable();
            return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(b$3)
          }
        }
      };
      if ((x1 !== null)) {
        var p16 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p17 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p16)) {
          if (ScalaJS.is.scala_util_Failure(p17)) {
            var x20 = ScalaJS.as.scala_util_Failure(p17);
            var b$4 = x20.exception__Ljava_lang_Throwable();
            return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(b$4)
          }
        }
      };
      throw new ScalaJS.c.scala_MatchError().init___O(x1)
    })
  })(combiner)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.mapAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, f) {
  return new ScalaJS.c.rx_ops_Mapper().init___Lrx_core_Rx__Lscala_Function1($$this, f)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, predicate) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(predicate$1) {
    return (function(x, y) {
      if (ScalaJS.uZ(predicate$1.apply__O__O(y))) {
        return y
      } else {
        return x
      }
    })
  })(predicate)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx = (function($$this, combiner) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, combiner)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx = (function($$this, interval, scheduler, ex) {
  return new ScalaJS.c.rx_ops_Debounce().init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext($$this, interval, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx = (function($$this, delay, scheduler, ex) {
  return new ScalaJS.c.rx_ops_Delay().init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext($$this, delay, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.hashCode$extension__Lrx_core_Rx__I = (function($$this) {
  return ScalaJS.objectHashCode($$this)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.equals$extension__Lrx_core_Rx__O__Z = (function($$this, x$1) {
  var x1 = x$1;
  matchEnd4: {
    if (ScalaJS.is.rx_ops_package$RxOps(x1)) {
      var jsx$1 = true;
      break matchEnd4
    };
    var jsx$1 = false;
    break matchEnd4
  };
  if (jsx$1) {
    if ((x$1 === null)) {
      var RxOps$1 = null
    } else {
      var RxOps$1 = ScalaJS.as.rx_ops_package$RxOps(x$1).source__Lrx_core_Rx()
    };
    return ScalaJS.anyRefEqEq($$this, RxOps$1)
  } else {
    return false
  }
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.equals$extension__Lrx_core_Rx__O__ = (function($$this, x$1) {
  return ScalaJS.bZ(this.equals$extension__Lrx_core_Rx__O__Z($$this, x$1))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.hashCode$extension__Lrx_core_Rx__ = (function($$this$2) {
  return ScalaJS.bI(this.hashCode$extension__Lrx_core_Rx__I($$this$2))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__ = (function($$this$3, delay, scheduler, ex) {
  return this.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx($$this$3, delay, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__ = (function($$this$4, interval, scheduler$2, ex$2) {
  return this.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx($$this$4, interval, scheduler$2, ex$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__ = (function($$this$5, combiner) {
  return this.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx($$this$5, combiner)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filterAll$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$6, predicate) {
  return this.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$6, predicate)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.mapAll$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$7, f) {
  return this.mapAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$7, f)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduce$extension__Lrx_core_Rx__Lscala_Function2__ = (function($$this$8, combiner$2) {
  return this.reduce$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx($$this$8, combiner$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filter$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$9, successPred) {
  return this.filter$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$9, successPred)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.map$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$10, f$2) {
  return this.map$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$10, f$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.skipFailures$extension__Lrx_core_Rx__ = (function($$this$11) {
  return this.skipFailures$extension__Lrx_core_Rx__Lrx_core_Rx($$this$11)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__ = (function($$this$12, callback, skipInitial) {
  return this.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__Lrx_core_Obs($$this$12, callback, skipInitial)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_package$RxOps$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_package$RxOps$.prototype = ScalaJS.c.rx_ops_package$RxOps$.prototype;
ScalaJS.is.rx_ops_package$RxOps$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_package$RxOps$)))
});
ScalaJS.as.rx_ops_package$RxOps$ = (function(obj) {
  if ((ScalaJS.is.rx_ops_package$RxOps$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.package$RxOps")
  }
});
ScalaJS.isArrayOf.rx_ops_package$RxOps$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_package$RxOps$)))
});
ScalaJS.asArrayOf.rx_ops_package$RxOps$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_package$RxOps$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.package$RxOps;", depth)
  }
});
ScalaJS.data.rx_ops_package$RxOps$ = new ScalaJS.ClassTypeData({
  rx_ops_package$RxOps$: 0
}, false, "rx.ops.package$RxOps$", ScalaJS.data.java_lang_Object, {
  rx_ops_package$RxOps$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.$classData = ScalaJS.data.rx_ops_package$RxOps$;
ScalaJS.moduleInstances.rx_ops_package$RxOps = undefined;
ScalaJS.modules.rx_ops_package$RxOps = (function() {
  if ((!ScalaJS.moduleInstances.rx_ops_package$RxOps)) {
    ScalaJS.moduleInstances.rx_ops_package$RxOps = new ScalaJS.c.rx_ops_package$RxOps$().init___()
  };
  return ScalaJS.moduleInstances.rx_ops_package$RxOps
});
//@ sourceMappingURL=package$RxOps$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/ops/package$RxOps$.js <==
/** @constructor */
ScalaJS.c.rx_ops_package$RxOps$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_ops_package$RxOps$.prototype.constructor = ScalaJS.c.rx_ops_package$RxOps$;
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__Lrx_core_Obs = (function($$this, callback$2, skipInitial$2) {
  return ScalaJS.modules.rx_package().Obs__Lrx_core_Obs$().apply__Lrx_core_Emitter__T__Z__Lscala_Function0__Lrx_core_Obs($$this, ("Foreach " + $$this.name__T()), skipInitial$2, new ScalaJS.c.scala_scalajs_runtime_AnonFunction0().init___Lscala_scalajs_js_Function0((function($$this$1, callback$1) {
    return (function() {
      callback$1.apply__O__O($$this$1.apply__O());
      return ScalaJS.bV(undefined)
    })
  })($$this, callback$2)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$default$2$extension__Lrx_core_Rx__Z = (function($$this) {
  return false
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.skipFailures$extension__Lrx_core_Rx__Lrx_core_Rx = (function($$this) {
  return this.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function() {
    return (function(x) {
      return ScalaJS.bZ(x.isSuccess__Z())
    })
  })()))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.map$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, f) {
  return new ScalaJS.c.rx_ops_Mapper().init___Lrx_core_Rx__Lscala_Function1($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction1().init___Lscala_scalajs_js_Function1((function(f$1) {
    return (function(y) {
      return y.map__Lscala_Function1__Lscala_util_Try(f$1)
    })
  })(f)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filter$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, successPred) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(successPred$1) {
    return (function(x, y) {
      var x1 = new ScalaJS.c.scala_Tuple2().init___O__O(x, y);
      if ((x1 !== null)) {
        var p3 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p3)) {
          var x4 = ScalaJS.as.scala_util_Success(p3);
          var value = x4.value__O();
          if (ScalaJS.uZ(successPred$1.apply__O__O(value))) {
            return new ScalaJS.c.scala_util_Success().init___O(value)
          }
        }
      };
      if ((x1 !== null)) {
        var p6 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p6)) {
          var x7 = ScalaJS.as.scala_util_Failure(p6);
          var thrown = x7.exception__Ljava_lang_Throwable();
          return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(thrown)
        }
      };
      if ((x1 !== null)) {
        var old = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        return old
      };
      throw new ScalaJS.c.scala_MatchError().init___O(x1)
    })
  })(successPred)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduce$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx = (function($$this, combiner) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(combiner$1) {
    return (function(x, y) {
      var x1 = new ScalaJS.c.scala_Tuple2().init___O__O(x, y);
      if ((x1 !== null)) {
        var p2 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p3 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p2)) {
          var x4 = ScalaJS.as.scala_util_Success(p2);
          var a = x4.value__O();
          if (ScalaJS.is.scala_util_Success(p3)) {
            var x5 = ScalaJS.as.scala_util_Success(p3);
            var b = x5.value__O();
            return new ScalaJS.c.scala_util_Success().init___O(combiner$1.apply__O__O__O(a, b))
          }
        }
      };
      if ((x1 !== null)) {
        var p6 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p7 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p6)) {
          if (ScalaJS.is.scala_util_Success(p7)) {
            var x10 = ScalaJS.as.scala_util_Success(p7);
            var b$2 = x10.value__O();
            return new ScalaJS.c.scala_util_Success().init___O(b$2)
          }
        }
      };
      if ((x1 !== null)) {
        var p11 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p12 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Success(p11)) {
          if (ScalaJS.is.scala_util_Failure(p12)) {
            var x15 = ScalaJS.as.scala_util_Failure(p12);
            var b$3 = x15.exception__Ljava_lang_Throwable();
            return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(b$3)
          }
        }
      };
      if ((x1 !== null)) {
        var p16 = ScalaJS.as.scala_util_Try(x1.$$und1__O());
        var p17 = ScalaJS.as.scala_util_Try(x1.$$und2__O());
        if (ScalaJS.is.scala_util_Failure(p16)) {
          if (ScalaJS.is.scala_util_Failure(p17)) {
            var x20 = ScalaJS.as.scala_util_Failure(p17);
            var b$4 = x20.exception__Ljava_lang_Throwable();
            return new ScalaJS.c.scala_util_Failure().init___Ljava_lang_Throwable(b$4)
          }
        }
      };
      throw new ScalaJS.c.scala_MatchError().init___O(x1)
    })
  })(combiner)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.mapAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, f) {
  return new ScalaJS.c.rx_ops_Mapper().init___Lrx_core_Rx__Lscala_Function1($$this, f)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx = (function($$this, predicate) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, new ScalaJS.c.scala_scalajs_runtime_AnonFunction2().init___Lscala_scalajs_js_Function2((function(predicate$1) {
    return (function(x, y) {
      if (ScalaJS.uZ(predicate$1.apply__O__O(y))) {
        return y
      } else {
        return x
      }
    })
  })(predicate)))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx = (function($$this, combiner) {
  return new ScalaJS.c.rx_ops_Reducer().init___Lrx_core_Rx__Lscala_Function2($$this, combiner)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx = (function($$this, interval, scheduler, ex) {
  return new ScalaJS.c.rx_ops_Debounce().init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext($$this, interval, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx = (function($$this, delay, scheduler, ex) {
  return new ScalaJS.c.rx_ops_Delay().init___Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext($$this, delay, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.hashCode$extension__Lrx_core_Rx__I = (function($$this) {
  return ScalaJS.objectHashCode($$this)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.equals$extension__Lrx_core_Rx__O__Z = (function($$this, x$1) {
  var x1 = x$1;
  matchEnd4: {
    if (ScalaJS.is.rx_ops_package$RxOps(x1)) {
      var jsx$1 = true;
      break matchEnd4
    };
    var jsx$1 = false;
    break matchEnd4
  };
  if (jsx$1) {
    if ((x$1 === null)) {
      var RxOps$1 = null
    } else {
      var RxOps$1 = ScalaJS.as.rx_ops_package$RxOps(x$1).source__Lrx_core_Rx()
    };
    return ScalaJS.anyRefEqEq($$this, RxOps$1)
  } else {
    return false
  }
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.equals$extension__Lrx_core_Rx__O__ = (function($$this, x$1) {
  return ScalaJS.bZ(this.equals$extension__Lrx_core_Rx__O__Z($$this, x$1))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.hashCode$extension__Lrx_core_Rx__ = (function($$this$2) {
  return ScalaJS.bI(this.hashCode$extension__Lrx_core_Rx__I($$this$2))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__ = (function($$this$3, delay, scheduler, ex) {
  return this.delay$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx($$this$3, delay, scheduler, ex)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__ = (function($$this$4, interval, scheduler$2, ex$2) {
  return this.debounce$extension__Lrx_core_Rx__Lscala_concurrent_duration_FiniteDuration__Lrx_ops_Scheduler__Lscala_concurrent_ExecutionContext__Lrx_core_Rx($$this$4, interval, scheduler$2, ex$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__ = (function($$this$5, combiner) {
  return this.reduceAll$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx($$this$5, combiner)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filterAll$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$6, predicate) {
  return this.filterAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$6, predicate)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.mapAll$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$7, f) {
  return this.mapAll$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$7, f)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.reduce$extension__Lrx_core_Rx__Lscala_Function2__ = (function($$this$8, combiner$2) {
  return this.reduce$extension__Lrx_core_Rx__Lscala_Function2__Lrx_core_Rx($$this$8, combiner$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.filter$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$9, successPred) {
  return this.filter$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$9, successPred)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.map$extension__Lrx_core_Rx__Lscala_Function1__ = (function($$this$10, f$2) {
  return this.map$extension__Lrx_core_Rx__Lscala_Function1__Lrx_core_Rx($$this$10, f$2)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.skipFailures$extension__Lrx_core_Rx__ = (function($$this$11) {
  return this.skipFailures$extension__Lrx_core_Rx__Lrx_core_Rx($$this$11)
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$default$2$extension__Lrx_core_Rx__ = (function($$this$12) {
  return ScalaJS.bZ(this.foreach$default$2$extension__Lrx_core_Rx__Z($$this$12))
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__ = (function($$this$13, callback, skipInitial) {
  return this.foreach$extension__Lrx_core_Rx__Lscala_Function1__Z__Lrx_core_Obs($$this$13, callback, skipInitial)
});
/** @constructor */
ScalaJS.inheritable.rx_ops_package$RxOps$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_ops_package$RxOps$.prototype = ScalaJS.c.rx_ops_package$RxOps$.prototype;
ScalaJS.is.rx_ops_package$RxOps$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_ops_package$RxOps$)))
});
ScalaJS.as.rx_ops_package$RxOps$ = (function(obj) {
  if ((ScalaJS.is.rx_ops_package$RxOps$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.ops.package$RxOps")
  }
});
ScalaJS.isArrayOf.rx_ops_package$RxOps$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_ops_package$RxOps$)))
});
ScalaJS.asArrayOf.rx_ops_package$RxOps$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_ops_package$RxOps$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.ops.package$RxOps;", depth)
  }
});
ScalaJS.data.rx_ops_package$RxOps$ = new ScalaJS.ClassTypeData({
  rx_ops_package$RxOps$: 0
}, false, "rx.ops.package$RxOps$", ScalaJS.data.java_lang_Object, {
  rx_ops_package$RxOps$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_ops_package$RxOps$.prototype.$classData = ScalaJS.data.rx_ops_package$RxOps$;
ScalaJS.moduleInstances.rx_ops_package$RxOps = undefined;
ScalaJS.modules.rx_ops_package$RxOps = (function() {
  if ((!ScalaJS.moduleInstances.rx_ops_package$RxOps)) {
    ScalaJS.moduleInstances.rx_ops_package$RxOps = new ScalaJS.c.rx_ops_package$RxOps$().init___()
  };
  return ScalaJS.moduleInstances.rx_ops_package$RxOps
});
//@ sourceMappingURL=package$RxOps$.js.map
